<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Auth\Events\PasswordReset;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Password;
use Illuminate\Support\Facades\Session;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Mail;


class AuthController extends Controller
{

    /**
     * 
     * @return response() 
     * 
     */
    public function login()
    {
        return view('auth.login');
    }

    /**
     * Write code on Method
     *
     * @return response()
     */
    public function registration()
    {
        return view('auth.registration');
    }

    public function forgotpassword()
    {
        return view('auth.requestnewpassword');
    }

    /**
     * Write code on Method
     *
     * @return response()
     */
    public function postLogin(Request $request)
    {
        $request->validate([
            'email' => 'required',
            'password' => 'required',
        ]);

        $credentials = $request->only('email', 'password');
        if (Auth::attempt($credentials)) {
            session(['login_success' => 'Login Succecssfull']);
            $loginId = Auth::id();
            Log::info('Login ID from session: ' . $loginId);
            $request->session()->put('login_id', $loginId); 
            return redirect()->route('landing')
                ->withSuccess('You have Successfully loggedin');
        }
        session(['login_failed' => 'Login Succecssfull']); 
        return redirect("login2")->withSuccess('Oppes! You have entered invalid credentials');
    }

    /**
     * Write code on Method
     *
     * @return response()
     */
    public function postRegistration(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'captcha' => 'required|captcha',
            
        ]);
        
        $request->validate([
            'first-name' => 'required',
            'last-name' => 'required',
            'phn' => 'required|min:10',
            'gender' => 'required',
            'dob' => 'required',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:8|regex:/^(?=.*[a-zA-Z])(?=.*\d)(?=.*[@$!%*#?&])[A-Za-z\d@$!%*#?&]{8,}$/',
        ], [
            'password.regex' => 'must be 8 characters long, include one letter, one digit, and one special character.',
        ]);

        $validator = Validator::make($request->all(), [
            'dob' => 'required|date|before_or_equal:' . now()->subYears(16)->format('Y-m-d'),
        ], [
            'dob.before_or_equal' => 'You must be at least 16 years old.',
        ]);
    
        if ($validator->fails()) {
            return redirect('reg2')->withErrors($validator);
            // Redirect back to the registration page with the validation errors
        }
        session(['registration_success' => 'Registration Succecssfull']); 
        $request->session()->put('user_data', $request->all());

        // $check = $this->create($data);

        return redirect()->route('register2.sendotp');
    }

    public function postForgotPassword(Request $request)
    {
        $request->validate(['email' => 'required|email']);

        $status = Password::sendResetLink(
            $request->only('email')
        );

        return $status === Password::RESET_LINK_SENT
            ? back()->with(['status' => __($status)])
            : back()->withErrors(['email' => __($status)]);
    }

    public function resetPassword(string $token)
    {
        return view('auth.password', ['token' => $token]);
    }


    public function postResetPassword(Request $request)
    {
        $request->validate([
            'token' => 'required',
            'email' => 'required|email',
            'password' => 'required|min:8|confirmed|regex:/^(?=.*[a-zA-Z])(?=.*\d)(?=.*[@$!%*#?&])[A-Za-z\d@$!%*#?&]{8,}$/',
            'password_confirmation' => 'required'
        ], [
            'password.regex' => 'must be 8 characters long, include one letter, one digit, and one special character.',
        ]);

        $status = Password::reset(
            $request->only('email', 'password', 'password_confirmation', 'token'),
            function (User $user, string $password) {
                $user->forceFill([
                    'password' => Hash::make($password)
                ])->setRememberToken(Str::random(60));

                $user->save();

                event(new PasswordReset($user));
            }
        );

        return $status === Password::PASSWORD_RESET
            ? redirect()->route('login')->with('status', __($status))
            : back()->withErrors(['email' => [__($status)]]);
    }
    /**
     * Write code on Method
     *
     * @return response()
     */

     public function showContactForm()
     {
         return view('contact');
     }
    public function dashboard()
    {
        if (Auth::check()) {
            return view('auth.dashboard');
        }

        return redirect("login")->withSuccess('Opps! You do not have access');
    }

    public function about()
    {
        
            return view('about');
        
    }

    
    public function cause()
    {
        
            return view('cause');
        
    }

    
    public function signs()
    {
        
            return view('signs');
        
    }

    
    public function treatments()
    {
        
            return view('treatments');
        
    }

    public function login2()
    {
        
            return view('auth.login2');
        
    }

    public function reg2()
    {
        
            return view('auth.reg2');
        
    }

    
    public function sendOTP(Request $request)
    {
        // Retrieve user data from the session
        $userData = $request->session()->get('user_data');
    
        if ($userData) {
            // Generate and send OTP via email
            $otp = mt_rand(100000, 999999); // Generate OTP
    
            // Save the OTP in the session for verification later
            $request->session()->put('otp', $otp);
    
            // Send the OTP via email
            Mail::send('emails.otp', ['otp' => $otp], function ($message) use ($userData) {
                $message->to($userData['email'])->subject('Your OTP for Registration');
            });
    
            // Redirect to the OTP entry page
            return redirect()->route('register2.otp');
        } else {
            // Handle the case when user data is missing in the session
            return redirect()->back()->withErrors('User data is missing');
        }
    }
    
    
        public function showOTPForm()
        {
            return view('auth.otp');
        }
    
        public function verifyOTP(Request $request)
        {
            $otp = $request->session()->get('otp');
    
            // Validate entered OTP with the stored one
            if ($otp == $request->input('otp')) {
                // OTP is correct, get user data from the session
                $userData = $request->session()->get('user_data');
                User::create([
                    'first_name' => $userData['first-name'],
                    'last_name' => $userData['last-name'],
                    'phone_number' => $userData['phn'],
                    'gender' => $userData['gender'],
                    'dob' => $userData['dob'],
                    'email' => $userData['email'],
                    'password' => Hash::make($userData['password']),
                    'otp_sent' => $otp
                ]);
                return redirect("login2")->withSuccess('Login Successfull');
            } else {
                return redirect()->route('register2.otp')->withErrors(['otp' => 'Invalid OTP. Please try again.']);
            }
        }
    

    /**
     * Write code on Method
     *
     * @return response()
     */
    /**
     * Write code on Method
     *
     * @return response()
     */

    public function questionnaire()
    {
        return view('questionnaire');
    }

    public function createQ(){
        $survey = Survey::where('name','PTSD survey')->first();

        return view ('questionnaire',['survey'=> $survey]);
    }

    public function store(Request $request){
        dd($request->all());
        
    }
    public function logout(Request $request)
{
    Auth::logout();
    $request->session()->invalidate();
    $request->session()->regenerateToken();

    return redirect('/')->withSuccess('You have successfully logged out');
}
}