<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use MattDaneshvar\Survey\Models\Entry;
use MattDaneshvar\Survey\Models\Survey;
use MattDaneshvar\Survey\Models\Question;
use App\Mail\SurveyResultsMail;
use Illuminate\Support\Facades\Mail;
use Barryvdh\DomPDF\Facade\Pdf as PDF;
use Illuminate\Support\Facades\DB;

class EntriesController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function create()
    {
        $survey = $this->survey();
        $loginId = session('login_id');
        Log::info('Login ID from session: ' . $loginId);

        return view('questionnaire', [
            'survey' => $survey,
            'participant_Id' => $loginId,

        ]);
    }

    public function store(Request $request)
    {
        Log::info('fun called');
        $survey = $this->survey();
        $answers = $this->validate($request, $survey->rules);

        $participantId = session('login_id');

        foreach ($answers as &$answer) {
            $answer = $this->mapAnswerToValue($answer);

        }

        $entry = new Entry();
        Log::info($answers);

        Log::info($request);

        $totalPoints = $request['user_result'];

        try {
            $entry
                ->for($survey)
                ->by(auth()->user())
                ->fromArray($answers)
                ->userResult($totalPoints)
                ->push();

            // Mail::to(auth()->user()->email)->send(new SurveyResultsMail($entry));

            return redirect()->route('feedback.form', ['entry' => $entry->id])->with('success', 'Survey Successfully submitted');
        } catch (\Exception $e) {
            return redirect('survey_results')->with('error', 'Error submitting survey');
        }
    }

    protected function mapAnswerToValue($answer)
    {
        $answerMap = [
            'Not at all' => 1,
            'A little bit' => 2,
            'Quite often' => 3,
            'Moderately' => 4,
            'Quite a bit' => 5,
        ];

        // If the answer is in the map, return the mapped value; otherwise, return the original answer
        return $answerMap[$answer] ?? $answer;
    }

    protected function survey()
    {
        return Survey::where('name', 'PTSD survey')->first();
    }

    public function getQuestion($questionId)
    {

        $retrievedQuestion = Question::find($questionId);

        Log::info("fuction is called " . $retrievedQuestion);

        if (!$retrievedQuestion) {
            abort(404, 'Question not found');
        }

        return view('survey::questions.single', ['question' => $retrievedQuestion]);
    }

    public function showSurveyResults()
    {
        $user = auth()->user();
        $survey = $this->survey();

        Log::info($survey);

        // Get previous surveys completed by the user with associated answers
        $previousSurveys = Entry::with(['answers', 'answers.question'])
            ->select(['*'])
            ->where('participant_id', $user->id)
            ->where('survey_id', $survey->id)
            ->orderBy('created_at', 'desc')
            ->get();

            $temp = [];


            foreach ($previousSurveys as $survey) {
                $temp[$survey['id']] = $this->getUserResultById($survey['id']);
            }

            


        Log::info("Previous Surveys...............................");


        return view('survey_results', compact('previousSurveys','temp'));
    }

    public function showSurveyResultsDetails($entryId)
    {
        $entry = Entry::with('answers.question')->findOrFail($entryId);

        $user = auth()->user();
        $survey = $this->survey();

        Log::info($survey);

        // Get previous surveys completed by the user
        $previousSurveys = Entry::where('participant_id', $user->id)
            ->where('survey_id', $survey->id)
            ->orderBy('created_at', 'desc')
            ->get();

            
            


        return view('survey_results', compact('entry', 'previousSurveys'));
    }

    public function getUserResultById($id){

        $results = DB::select("SELECT user_result FROM entries WHERE id = :id", [
            'id' => $id,
        ]);

        // Access the user_result value from the result
        if (!empty($results)) {
            $userResult = $results[0]->user_result;
            // Do something with $userResult
            Log::info($userResult);
            return $userResult.'';
        } else {
            // Handle the case where no results are found
            Log::info('user result failed');
            return '0';

        }
    }

    public function downloadPDF($entryId)
    {
        $entry = Entry::with('answers.question', 'participant')->findOrFail($entryId);

            Log::info(";............".$entry['id']);
            $temp['user_result'] = $this->getUserResultById($entry['id']);

        $pdf = PDF::loadView('pdfs.survey_results', compact('entry','temp'));

        return $pdf->download('survey_results.pdf');
    }

    public function emailPDF($entryId)
    {
        $entry = Entry::with('answers.question', 'participant')->findOrFail($entryId);

        $temp['user_result'] = $this->getUserResultById($entry['id']);

        $pdf = PDF::loadView('pdfs.survey_results', compact('entry','temp'));

        Mail::to($entry->participant->email)->send(new SurveyResultsMail($pdf));

        return redirect()->route('survey_results')->with('success', 'PDF sent by email successfully');
    }

}
