<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Feedback;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Mail;

class FeedbackController extends Controller
{
    public function showForm($entry = null)
    {
        return view('feedback', ['entry' => $entry]);
    }

    public function submitForm(Request $request)
    {
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'phone_number' => 'nullable|string|max:20',
            'experience' => 'required|in:good,bad',
            'comments' => 'required|string',
        ]);

        Feedback::create($validatedData);

        // Send email to admin
        $this->sendEmailToAdmin($validatedData);

        return redirect()->route('survey_results')->with('success', 'Feedback submitted successfully!');
    }

    private function sendEmailToAdmin($data)
    {
        // Adjust this with your admin email and customize the email view
        $adminEmail = Config::get('mail.from.address');

        Mail::to($adminEmail)->send(new \App\Mail\FeedbackMail($data));
    }
}
